import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * The Spot Elastigroup Resource allows you to create, update, manage, and delete Spot Elastigroups easily with CloudFormation
 *
 * @schema CfnGroupProps
 */
export interface CfnGroupProps {
    /**
     * @schema CfnGroupProps#credentials
     */
    readonly credentials: CfnGroupPropsCredentials;
    /**
     * @schema CfnGroupProps#group
     */
    readonly group?: CfnGroupPropsGroup;
}
/**
 * Converts an object of type 'CfnGroupProps' to JSON representation.
 */
export declare function toJson_CfnGroupProps(obj: CfnGroupProps | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsCredentials
 */
export interface CfnGroupPropsCredentials {
    /**
     * @schema CfnGroupPropsCredentials#accountId
     */
    readonly accountId?: string;
    /**
     * @schema CfnGroupPropsCredentials#accessToken
     */
    readonly accessToken?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsCredentials' to JSON representation.
 */
export declare function toJson_CfnGroupPropsCredentials(obj: CfnGroupPropsCredentials | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroup
 */
export interface CfnGroupPropsGroup {
    /**
     * @schema CfnGroupPropsGroup#groupId
     */
    readonly groupId?: string;
    /**
     * The name of the elastigroup
     *
     * @schema CfnGroupPropsGroup#name
     */
    readonly name?: string;
    /**
     * The description of the elastigroup
     *
     * @schema CfnGroupPropsGroup#description
     */
    readonly description?: string;
    /**
     * @schema CfnGroupPropsGroup#createdAt
     */
    readonly createdAt?: string;
    /**
     * @schema CfnGroupPropsGroup#updatedAt
     */
    readonly updatedAt?: string;
    /**
     * @schema CfnGroupPropsGroup#region
     */
    readonly region?: string;
    /**
     * @schema CfnGroupPropsGroup#strategy
     */
    readonly strategy?: CfnGroupPropsGroupStrategy;
    /**
     * @schema CfnGroupPropsGroup#compute
     */
    readonly compute?: CfnGroupPropsGroupCompute;
    /**
     * @schema CfnGroupPropsGroup#capacity
     */
    readonly capacity?: CfnGroupPropsGroupCapacity;
    /**
     * @schema CfnGroupPropsGroup#scaling
     */
    readonly scaling?: CfnGroupPropsGroupScaling;
    /**
     * @schema CfnGroupPropsGroup#thirdPartiesIntegration
     */
    readonly thirdPartiesIntegration?: CfnGroupPropsGroupThirdPartiesIntegration;
    /**
     * @schema CfnGroupPropsGroup#scheduling
     */
    readonly scheduling?: CfnGroupPropsGroupScheduling;
}
/**
 * Converts an object of type 'CfnGroupPropsGroup' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroup(obj: CfnGroupPropsGroup | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupStrategy
 */
export interface CfnGroupPropsGroupStrategy {
    /**
     * @schema CfnGroupPropsGroupStrategy#risk
     */
    readonly risk?: number;
    /**
     * @schema CfnGroupPropsGroupStrategy#immediateODRecoverThreshold
     */
    readonly immediateOdRecoverThreshold?: number;
    /**
     * @schema CfnGroupPropsGroupStrategy#restrictSingleAz
     */
    readonly restrictSingleAz?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategy#utilizeReservedInstances
     */
    readonly utilizeReservedInstances?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategy#utilizeCommitments
     */
    readonly utilizeCommitments?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategy#onDemandCount
     */
    readonly onDemandCount?: number;
    /**
     * @schema CfnGroupPropsGroupStrategy#availabilityVsCost
     */
    readonly availabilityVsCost?: string;
    /**
     * @schema CfnGroupPropsGroupStrategy#drainingTimeout
     */
    readonly drainingTimeout?: number;
    /**
     * @schema CfnGroupPropsGroupStrategy#spinUpTime
     */
    readonly spinUpTime?: number;
    /**
     * @schema CfnGroupPropsGroupStrategy#fallbackToOd
     */
    readonly fallbackToOd?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategy#lifetimePeriod
     */
    readonly lifetimePeriod?: string;
    /**
     * @schema CfnGroupPropsGroupStrategy#signals
     */
    readonly signals?: CfnGroupPropsGroupStrategySignals[];
    /**
     * @schema CfnGroupPropsGroupStrategy#considerODPricing
     */
    readonly considerOdPricing?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategy#scalingStrategy
     */
    readonly scalingStrategy?: CfnGroupPropsGroupStrategyScalingStrategy;
    /**
     * @schema CfnGroupPropsGroupStrategy#persistence
     */
    readonly persistence?: CfnGroupPropsGroupStrategyPersistence;
    /**
     * @schema CfnGroupPropsGroupStrategy#revertToSpot
     */
    readonly revertToSpot?: CfnGroupPropsGroupStrategyRevertToSpot;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupStrategy' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupStrategy(obj: CfnGroupPropsGroupStrategy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupCompute
 */
export interface CfnGroupPropsGroupCompute {
    /**
     * @schema CfnGroupPropsGroupCompute#elasticIps
     */
    readonly elasticIps?: string[];
    /**
     * @schema CfnGroupPropsGroupCompute#privateIps
     */
    readonly privateIps?: string[];
    /**
     * @schema CfnGroupPropsGroupCompute#volumeAttachments
     */
    readonly volumeAttachments?: CfnGroupPropsGroupComputeVolumeAttachments;
    /**
     * @schema CfnGroupPropsGroupCompute#instanceTypes
     */
    readonly instanceTypes?: CfnGroupPropsGroupComputeInstanceTypes;
    /**
     * @schema CfnGroupPropsGroupCompute#availabilityZones
     */
    readonly availabilityZones?: CfnGroupPropsGroupComputeAvailabilityZones[];
    /**
     * @schema CfnGroupPropsGroupCompute#subnetIds
     */
    readonly subnetIds?: string[];
    /**
     * @schema CfnGroupPropsGroupCompute#preferredAvailabilityZones
     */
    readonly preferredAvailabilityZones?: string[];
    /**
     * @schema CfnGroupPropsGroupCompute#product
     */
    readonly product?: string;
    /**
     * @schema CfnGroupPropsGroupCompute#ebsVolumePool
     */
    readonly ebsVolumePool?: CfnGroupPropsGroupComputeEbsVolumePool[];
    /**
     * @schema CfnGroupPropsGroupCompute#launchSpecification
     */
    readonly launchSpecification?: CfnGroupPropsGroupComputeLaunchSpecification;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupCompute' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupCompute(obj: CfnGroupPropsGroupCompute | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupCapacity
 */
export interface CfnGroupPropsGroupCapacity {
    /**
     * @schema CfnGroupPropsGroupCapacity#minimum
     */
    readonly minimum?: number;
    /**
     * @schema CfnGroupPropsGroupCapacity#maximum
     */
    readonly maximum?: number;
    /**
     * @schema CfnGroupPropsGroupCapacity#target
     */
    readonly target?: number;
    /**
     * @schema CfnGroupPropsGroupCapacity#unit
     */
    readonly unit?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupCapacity' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupCapacity(obj: CfnGroupPropsGroupCapacity | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupScaling
 */
export interface CfnGroupPropsGroupScaling {
    /**
     * @schema CfnGroupPropsGroupScaling#multipleMetrics
     */
    readonly multipleMetrics?: CfnGroupPropsGroupScalingMultipleMetrics;
    /**
     * @schema CfnGroupPropsGroupScaling#up
     */
    readonly up?: ScalingUpPolicy[];
    /**
     * @schema CfnGroupPropsGroupScaling#down
     */
    readonly down?: ScalingDownPolicy[];
    /**
     * @schema CfnGroupPropsGroupScaling#target
     */
    readonly target?: ScalingTargetPolicy[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupScaling' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupScaling(obj: CfnGroupPropsGroupScaling | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegration
 */
export interface CfnGroupPropsGroupThirdPartiesIntegration {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#rancher
     */
    readonly rancher?: CfnGroupPropsGroupThirdPartiesIntegrationRancher;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#mesosphere
     */
    readonly mesosphere?: CfnGroupPropsGroupThirdPartiesIntegrationMesosphere;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#elasticBeanstalk
     */
    readonly elasticBeanstalk?: CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#ecs
     */
    readonly ecs?: Ecs;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#mlbRuntime
     */
    readonly mlbRuntime?: CfnGroupPropsGroupThirdPartiesIntegrationMlbRuntime;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#kubernetes
     */
    readonly kubernetes?: Kubernetes;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#rightScale
     */
    readonly rightScale?: CfnGroupPropsGroupThirdPartiesIntegrationRightScale;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#opsWorks
     */
    readonly opsWorks?: CfnGroupPropsGroupThirdPartiesIntegrationOpsWorks;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#codeDeploy
     */
    readonly codeDeploy?: CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#chef
     */
    readonly chef?: CfnGroupPropsGroupThirdPartiesIntegrationChef;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#nomad
     */
    readonly nomad?: Nomad;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#dockerSwarm
     */
    readonly dockerSwarm?: DockerSwarm;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#route53
     */
    readonly route53?: CfnGroupPropsGroupThirdPartiesIntegrationRoute53;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#gitlab
     */
    readonly gitlab?: CfnGroupPropsGroupThirdPartiesIntegrationGitlab;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#datadog
     */
    readonly datadog?: CfnGroupPropsGroupThirdPartiesIntegrationDatadog;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegration#jenkins
     */
    readonly jenkins?: CfnGroupPropsGroupThirdPartiesIntegrationJenkins;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegration' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegration(obj: CfnGroupPropsGroupThirdPartiesIntegration | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupScheduling
 */
export interface CfnGroupPropsGroupScheduling {
    /**
     * @schema CfnGroupPropsGroupScheduling#tasks
     */
    readonly tasks?: Task[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupScheduling' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupScheduling(obj: CfnGroupPropsGroupScheduling | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupStrategySignals
 */
export interface CfnGroupPropsGroupStrategySignals {
    /**
     * @schema CfnGroupPropsGroupStrategySignals#name
     */
    readonly name?: string;
    /**
     * @schema CfnGroupPropsGroupStrategySignals#timeout
     */
    readonly timeout?: number;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupStrategySignals' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupStrategySignals(obj: CfnGroupPropsGroupStrategySignals | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupStrategyScalingStrategy
 */
export interface CfnGroupPropsGroupStrategyScalingStrategy {
    /**
     * @schema CfnGroupPropsGroupStrategyScalingStrategy#terminateAtEndOfBillingHour
     */
    readonly terminateAtEndOfBillingHour?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategyScalingStrategy#terminationPolicy
     */
    readonly terminationPolicy?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupStrategyScalingStrategy' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupStrategyScalingStrategy(obj: CfnGroupPropsGroupStrategyScalingStrategy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupStrategyPersistence
 */
export interface CfnGroupPropsGroupStrategyPersistence {
    /**
     * @schema CfnGroupPropsGroupStrategyPersistence#shouldPersistBlockDevices
     */
    readonly shouldPersistBlockDevices?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategyPersistence#shouldPersistRootDevice
     */
    readonly shouldPersistRootDevice?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategyPersistence#shouldPersistPrivateIp
     */
    readonly shouldPersistPrivateIp?: boolean;
    /**
     * @schema CfnGroupPropsGroupStrategyPersistence#blockDevicesMode
     */
    readonly blockDevicesMode?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupStrategyPersistence' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupStrategyPersistence(obj: CfnGroupPropsGroupStrategyPersistence | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupStrategyRevertToSpot
 */
export interface CfnGroupPropsGroupStrategyRevertToSpot {
    /**
     * @schema CfnGroupPropsGroupStrategyRevertToSpot#performAt
     */
    readonly performAt?: string;
    /**
     * @schema CfnGroupPropsGroupStrategyRevertToSpot#timeWindows
     */
    readonly timeWindows?: string[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupStrategyRevertToSpot' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupStrategyRevertToSpot(obj: CfnGroupPropsGroupStrategyRevertToSpot | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeVolumeAttachments
 */
export interface CfnGroupPropsGroupComputeVolumeAttachments {
    /**
     * @schema CfnGroupPropsGroupComputeVolumeAttachments#volumes
     */
    readonly volumes?: CfnGroupPropsGroupComputeVolumeAttachmentsVolumes[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeVolumeAttachments' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeVolumeAttachments(obj: CfnGroupPropsGroupComputeVolumeAttachments | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeInstanceTypes
 */
export interface CfnGroupPropsGroupComputeInstanceTypes {
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypes#onDemand
     */
    readonly onDemand?: string;
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypes#onDemandTypes
     */
    readonly onDemandTypes?: string[];
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypes#spot
     */
    readonly spot?: string[];
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypes#resourceRequirements
     */
    readonly resourceRequirements?: CfnGroupPropsGroupComputeInstanceTypesResourceRequirements;
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypes#weights
     */
    readonly weights?: CfnGroupPropsGroupComputeInstanceTypesWeights[];
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypes#preferredSpot
     */
    readonly preferredSpot?: string[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeInstanceTypes' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeInstanceTypes(obj: CfnGroupPropsGroupComputeInstanceTypes | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeAvailabilityZones
 */
export interface CfnGroupPropsGroupComputeAvailabilityZones {
    /**
     * @schema CfnGroupPropsGroupComputeAvailabilityZones#name
     */
    readonly name?: string;
    /**
     * @schema CfnGroupPropsGroupComputeAvailabilityZones#subnetId
     */
    readonly subnetId?: string;
    /**
     * @schema CfnGroupPropsGroupComputeAvailabilityZones#subnetIds
     */
    readonly subnetIds?: string[];
    /**
     * @schema CfnGroupPropsGroupComputeAvailabilityZones#placementGroupName
     */
    readonly placementGroupName?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeAvailabilityZones' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeAvailabilityZones(obj: CfnGroupPropsGroupComputeAvailabilityZones | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeEbsVolumePool
 */
export interface CfnGroupPropsGroupComputeEbsVolumePool {
    /**
     * @schema CfnGroupPropsGroupComputeEbsVolumePool#deviceName
     */
    readonly deviceName?: string;
    /**
     * @schema CfnGroupPropsGroupComputeEbsVolumePool#volumeIds
     */
    readonly volumeIds?: string[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeEbsVolumePool' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeEbsVolumePool(obj: CfnGroupPropsGroupComputeEbsVolumePool | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecification
 */
export interface CfnGroupPropsGroupComputeLaunchSpecification {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#loadBalancerName
     */
    readonly loadBalancerName?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#loadBalancerNames
     */
    readonly loadBalancerNames?: string[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#securityGroupIds
     */
    readonly securityGroupIds?: string[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#loadBalancersConfig
     */
    readonly loadBalancersConfig?: LoadBalancersConfig;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#itf
     */
    readonly itf?: CfnGroupPropsGroupComputeLaunchSpecificationItf;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#healthCheckUnhealthyDurationBeforeReplacement
     */
    readonly healthCheckUnhealthyDurationBeforeReplacement?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#monitoring
     */
    readonly monitoring?: boolean;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#ebsOptimized
     */
    readonly ebsOptimized?: boolean;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#imageId
     */
    readonly imageId?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#images
     */
    readonly images?: CfnGroupPropsGroupComputeLaunchSpecificationImages[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#keyPair
     */
    readonly keyPair?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#userData
     */
    readonly userData?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#shutdownScript
     */
    readonly shutdownScript?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#tags
     */
    readonly tags?: Tag[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#healthCheckType
     */
    readonly healthCheckType?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#healthCheckGracePeriod
     */
    readonly healthCheckGracePeriod?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#blockDeviceMappings
     */
    readonly blockDeviceMappings?: BlockDeviceMapping[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#iamRole
     */
    readonly iamRole?: CfnGroupPropsGroupComputeLaunchSpecificationIamRole;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#creditSpecification
     */
    readonly creditSpecification?: CfnGroupPropsGroupComputeLaunchSpecificationCreditSpecification;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#networkInterfaces
     */
    readonly networkInterfaces?: CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#cpuOptions
     */
    readonly cpuOptions?: CfnGroupPropsGroupComputeLaunchSpecificationCpuOptions;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#resourceTagSpecification
     */
    readonly resourceTagSpecification?: CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#metadataOptions
     */
    readonly metadataOptions?: CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecification#autoHealing
     */
    readonly autoHealing?: boolean;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecification' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecification(obj: CfnGroupPropsGroupComputeLaunchSpecification | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupScalingMultipleMetrics
 */
export interface CfnGroupPropsGroupScalingMultipleMetrics {
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetrics#metrics
     */
    readonly metrics?: CfnGroupPropsGroupScalingMultipleMetricsMetrics[];
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetrics#expressions
     */
    readonly expressions?: CfnGroupPropsGroupScalingMultipleMetricsExpressions[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupScalingMultipleMetrics' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupScalingMultipleMetrics(obj: CfnGroupPropsGroupScalingMultipleMetrics | undefined): Record<string, any> | undefined;
/**
 * @schema ScalingUpPolicy
 */
export interface ScalingUpPolicy {
    /**
     * @schema ScalingUpPolicy#policyName
     */
    readonly policyName?: string;
    /**
     * @schema ScalingUpPolicy#namespace
     */
    readonly namespace?: string;
    /**
     * @schema ScalingUpPolicy#source
     */
    readonly source?: string;
    /**
     * @schema ScalingUpPolicy#metricName
     */
    readonly metricName?: string;
    /**
     * @schema ScalingUpPolicy#dimension
     */
    readonly dimension?: Dimension[];
    /**
     * @schema ScalingUpPolicy#statistic
     */
    readonly statistic?: string;
    /**
     * @schema ScalingUpPolicy#extendedStatistic
     */
    readonly extendedStatistic?: string;
    /**
     * @schema ScalingUpPolicy#unit
     */
    readonly unit?: string;
    /**
     * @schema ScalingUpPolicy#threshold
     */
    readonly threshold?: number;
    /**
     * @schema ScalingUpPolicy#stepAdjustments
     */
    readonly stepAdjustments?: ScaleUpStepAdjustment[];
    /**
     * @schema ScalingUpPolicy#minTargetCapacity
     */
    readonly minTargetCapacity?: number;
    /**
     * @schema ScalingUpPolicy#period
     */
    readonly period?: number;
    /**
     * @schema ScalingUpPolicy#evaluationPeriods
     */
    readonly evaluationPeriods?: number;
    /**
     * @schema ScalingUpPolicy#cooldown
     */
    readonly cooldown?: number;
    /**
     * @schema ScalingUpPolicy#action
     */
    readonly action?: ScaleUpAction;
    /**
     * @schema ScalingUpPolicy#operator
     */
    readonly operator?: string;
    /**
     * @schema ScalingUpPolicy#isEnabled
     */
    readonly isEnabled?: boolean;
}
/**
 * Converts an object of type 'ScalingUpPolicy' to JSON representation.
 */
export declare function toJson_ScalingUpPolicy(obj: ScalingUpPolicy | undefined): Record<string, any> | undefined;
/**
 * @schema ScalingDownPolicy
 */
export interface ScalingDownPolicy {
    /**
     * @schema ScalingDownPolicy#policyName
     */
    readonly policyName?: string;
    /**
     * @schema ScalingDownPolicy#namespace
     */
    readonly namespace?: string;
    /**
     * @schema ScalingDownPolicy#source
     */
    readonly source?: string;
    /**
     * @schema ScalingDownPolicy#metricName
     */
    readonly metricName?: string;
    /**
     * @schema ScalingDownPolicy#dimension
     */
    readonly dimension?: Dimension[];
    /**
     * @schema ScalingDownPolicy#statistic
     */
    readonly statistic?: string;
    /**
     * @schema ScalingDownPolicy#extendedStatistic
     */
    readonly extendedStatistic?: string;
    /**
     * @schema ScalingDownPolicy#unit
     */
    readonly unit?: string;
    /**
     * @schema ScalingDownPolicy#threshold
     */
    readonly threshold?: number;
    /**
     * @schema ScalingDownPolicy#stepAdjustments
     */
    readonly stepAdjustments?: ScaleDownStepAdjustment[];
    /**
     * @schema ScalingDownPolicy#maxTargetCapacity
     */
    readonly maxTargetCapacity?: number;
    /**
     * @schema ScalingDownPolicy#period
     */
    readonly period?: number;
    /**
     * @schema ScalingDownPolicy#evaluationPeriods
     */
    readonly evaluationPeriods?: number;
    /**
     * @schema ScalingDownPolicy#cooldown
     */
    readonly cooldown?: number;
    /**
     * @schema ScalingDownPolicy#action
     */
    readonly action?: ScaleDownAction;
    /**
     * @schema ScalingDownPolicy#operator
     */
    readonly operator?: string;
    /**
     * @schema ScalingDownPolicy#isEnabled
     */
    readonly isEnabled?: boolean;
}
/**
 * Converts an object of type 'ScalingDownPolicy' to JSON representation.
 */
export declare function toJson_ScalingDownPolicy(obj: ScalingDownPolicy | undefined): Record<string, any> | undefined;
/**
 * @schema ScalingTargetPolicy
 */
export interface ScalingTargetPolicy {
    /**
     * @schema ScalingTargetPolicy#policyName
     */
    readonly policyName?: string;
    /**
     * @schema ScalingTargetPolicy#namespace
     */
    readonly namespace?: string;
    /**
     * @schema ScalingTargetPolicy#source
     */
    readonly source?: string;
    /**
     * @schema ScalingTargetPolicy#metricName
     */
    readonly metricName?: string;
    /**
     * @schema ScalingTargetPolicy#dimension
     */
    readonly dimension?: Dimension[];
    /**
     * @schema ScalingTargetPolicy#statistic
     */
    readonly statistic?: string;
    /**
     * @schema ScalingTargetPolicy#unit
     */
    readonly unit?: string;
    /**
     * @schema ScalingTargetPolicy#period
     */
    readonly period?: number;
    /**
     * @schema ScalingTargetPolicy#evaluationPeriods
     */
    readonly evaluationPeriods?: number;
    /**
     * @schema ScalingTargetPolicy#cooldown
     */
    readonly cooldown?: number;
    /**
     * @schema ScalingTargetPolicy#target
     */
    readonly target?: number;
    /**
     * @schema ScalingTargetPolicy#predictive
     */
    readonly predictive?: ScalingTargetPolicyPredictive;
}
/**
 * Converts an object of type 'ScalingTargetPolicy' to JSON representation.
 */
export declare function toJson_ScalingTargetPolicy(obj: ScalingTargetPolicy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationRancher
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationRancher {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRancher#version
     */
    readonly version?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRancher#accessKey
     */
    readonly accessKey?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRancher#secretKey
     */
    readonly secretKey?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRancher#masterHost
     */
    readonly masterHost?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationRancher' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationRancher(obj: CfnGroupPropsGroupThirdPartiesIntegrationRancher | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationMesosphere
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationMesosphere {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationMesosphere#apiServer
     */
    readonly apiServer?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationMesosphere' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationMesosphere(obj: CfnGroupPropsGroupThirdPartiesIntegrationMesosphere | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk#environmentId
     */
    readonly environmentId?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk#deploymentPreferences
     */
    readonly deploymentPreferences?: CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk#managedActions
     */
    readonly managedActions?: CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActions;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk(obj: CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalk | undefined): Record<string, any> | undefined;
/**
 * @schema Ecs
 */
export interface Ecs {
    /**
     * @schema Ecs#clusterName
     */
    readonly clusterName?: string;
    /**
     * @schema Ecs#autoScale
     */
    readonly autoScale?: EcsAutoScale;
    /**
     * @schema Ecs#batch
     */
    readonly batch?: EcsBatch;
    /**
     * @schema Ecs#optimizeImages
     */
    readonly optimizeImages?: EcsOptimizeImages;
}
/**
 * Converts an object of type 'Ecs' to JSON representation.
 */
export declare function toJson_Ecs(obj: Ecs | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationMlbRuntime
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationMlbRuntime {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationMlbRuntime#deploymentId
     */
    readonly deploymentId?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationMlbRuntime' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationMlbRuntime(obj: CfnGroupPropsGroupThirdPartiesIntegrationMlbRuntime | undefined): Record<string, any> | undefined;
/**
 * @schema Kubernetes
 */
export interface Kubernetes {
    /**
     * @schema Kubernetes#integrationMode
     */
    readonly integrationMode?: string;
    /**
     * @schema Kubernetes#clusterIdentifier
     */
    readonly clusterIdentifier?: string;
    /**
     * @schema Kubernetes#apiServer
     */
    readonly apiServer?: string;
    /**
     * @schema Kubernetes#token
     */
    readonly token?: string;
    /**
     * @schema Kubernetes#autoScale
     */
    readonly autoScale?: KubernetesAutoScale;
}
/**
 * Converts an object of type 'Kubernetes' to JSON representation.
 */
export declare function toJson_Kubernetes(obj: Kubernetes | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationRightScale
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationRightScale {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRightScale#accountId
     */
    readonly accountId?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRightScale#refreshToken
     */
    readonly refreshToken?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRightScale#region
     */
    readonly region?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationRightScale' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationRightScale(obj: CfnGroupPropsGroupThirdPartiesIntegrationRightScale | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationOpsWorks
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationOpsWorks {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationOpsWorks#layerId
     */
    readonly layerId?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationOpsWorks#stackType
     */
    readonly stackType?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationOpsWorks' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationOpsWorks(obj: CfnGroupPropsGroupThirdPartiesIntegrationOpsWorks | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy#cleanUpOnFailure
     */
    readonly cleanUpOnFailure?: boolean;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy#terminateInstanceOnFailure
     */
    readonly terminateInstanceOnFailure?: boolean;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy#deploymentGroups
     */
    readonly deploymentGroups?: CfnGroupPropsGroupThirdPartiesIntegrationCodeDeployDeploymentGroups[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy(obj: CfnGroupPropsGroupThirdPartiesIntegrationCodeDeploy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationChef
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationChef {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationChef#chefServer
     */
    readonly chefServer?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationChef#organization
     */
    readonly organization?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationChef#user
     */
    readonly user?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationChef#pemKey
     */
    readonly pemKey?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationChef#chefVersion
     */
    readonly chefVersion?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationChef' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationChef(obj: CfnGroupPropsGroupThirdPartiesIntegrationChef | undefined): Record<string, any> | undefined;
/**
 * @schema Nomad
 */
export interface Nomad {
    /**
     * @schema Nomad#masterHost
     */
    readonly masterHost?: string;
    /**
     * @schema Nomad#masterPort
     */
    readonly masterPort?: number;
    /**
     * @schema Nomad#aclToken
     */
    readonly aclToken?: string;
    /**
     * @schema Nomad#autoScale
     */
    readonly autoScale?: NomadAutoScale;
    /**
     * @schema Nomad#tlsConfig
     */
    readonly tlsConfig?: TlsConfig;
}
/**
 * Converts an object of type 'Nomad' to JSON representation.
 */
export declare function toJson_Nomad(obj: Nomad | undefined): Record<string, any> | undefined;
/**
 * @schema DockerSwarm
 */
export interface DockerSwarm {
    /**
     * @schema DockerSwarm#masterHost
     */
    readonly masterHost?: string;
    /**
     * @schema DockerSwarm#masterPort
     */
    readonly masterPort?: number;
    /**
     * @schema DockerSwarm#autoScale
     */
    readonly autoScale?: DockerSwarmAutoScale;
    /**
     * @schema DockerSwarm#tlsConfig
     */
    readonly tlsConfig?: TlsConfig;
}
/**
 * Converts an object of type 'DockerSwarm' to JSON representation.
 */
export declare function toJson_DockerSwarm(obj: DockerSwarm | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationRoute53 {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53#domains
     */
    readonly domains?: CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationRoute53' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationRoute53(obj: CfnGroupPropsGroupThirdPartiesIntegrationRoute53 | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationGitlab
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationGitlab {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationGitlab#runner
     */
    readonly runner?: CfnGroupPropsGroupThirdPartiesIntegrationGitlabRunner;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationGitlab' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationGitlab(obj: CfnGroupPropsGroupThirdPartiesIntegrationGitlab | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationDatadog
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationDatadog {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationDatadog#id
     */
    readonly id?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationDatadog#metricsToReport
     */
    readonly metricsToReport?: CfnGroupPropsGroupThirdPartiesIntegrationDatadogMetricsToReport;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationDatadog' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationDatadog(obj: CfnGroupPropsGroupThirdPartiesIntegrationDatadog | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkins
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationJenkins {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkins#connectionMethod
     */
    readonly connectionMethod?: CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationJenkins' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationJenkins(obj: CfnGroupPropsGroupThirdPartiesIntegrationJenkins | undefined): Record<string, any> | undefined;
/**
 * @schema Task
 */
export interface Task {
    /**
     * @schema Task#isEnabled
     */
    readonly isEnabled?: boolean;
    /**
     * @schema Task#taskType
     */
    readonly taskType?: string;
    /**
     * @schema Task#cronExpression
     */
    readonly cronExpression?: string;
    /**
     * @schema Task#scaleTargetCapacity
     */
    readonly scaleTargetCapacity?: number;
    /**
     * @schema Task#scaleMinCapacity
     */
    readonly scaleMinCapacity?: number;
    /**
     * @schema Task#scaleMaxCapacity
     */
    readonly scaleMaxCapacity?: number;
    /**
     * @schema Task#batchSizePercentage
     */
    readonly batchSizePercentage?: number;
    /**
     * @schema Task#gracePeriod
     */
    readonly gracePeriod?: number;
    /**
     * @schema Task#frequency
     */
    readonly frequency?: string;
    /**
     * @schema Task#startTime
     */
    readonly startTime?: string;
    /**
     * @schema Task#adjustment
     */
    readonly adjustment?: number;
    /**
     * @schema Task#adjustmentPercentage
     */
    readonly adjustmentPercentage?: number;
    /**
     * @schema Task#targetCapacity
     */
    readonly targetCapacity?: number;
    /**
     * @schema Task#minCapacity
     */
    readonly minCapacity?: number;
    /**
     * @schema Task#maxCapacity
     */
    readonly maxCapacity?: number;
}
/**
 * Converts an object of type 'Task' to JSON representation.
 */
export declare function toJson_Task(obj: Task | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeVolumeAttachmentsVolumes
 */
export interface CfnGroupPropsGroupComputeVolumeAttachmentsVolumes {
    /**
     * @schema CfnGroupPropsGroupComputeVolumeAttachmentsVolumes#deviceName
     */
    readonly deviceName?: string;
    /**
     * @schema CfnGroupPropsGroupComputeVolumeAttachmentsVolumes#volumeId
     */
    readonly volumeId?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeVolumeAttachmentsVolumes' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeVolumeAttachmentsVolumes(obj: CfnGroupPropsGroupComputeVolumeAttachmentsVolumes | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeInstanceTypesResourceRequirements
 */
export interface CfnGroupPropsGroupComputeInstanceTypesResourceRequirements {
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypesResourceRequirements#requiredVCpu
     */
    readonly requiredVCpu?: ResourceRequirement;
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypesResourceRequirements#requiredGpu
     */
    readonly requiredGpu?: ResourceRequirement;
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypesResourceRequirements#requiredMemory
     */
    readonly requiredMemory?: ResourceRequirement;
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypesResourceRequirements#excludedInstanceGenerations
     */
    readonly excludedInstanceGenerations?: string[];
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypesResourceRequirements#excludedInstanceFamilies
     */
    readonly excludedInstanceFamilies?: string[];
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypesResourceRequirements#excludedInstanceTypes
     */
    readonly excludedInstanceTypes?: string[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeInstanceTypesResourceRequirements' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeInstanceTypesResourceRequirements(obj: CfnGroupPropsGroupComputeInstanceTypesResourceRequirements | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeInstanceTypesWeights
 */
export interface CfnGroupPropsGroupComputeInstanceTypesWeights {
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypesWeights#instanceType
     */
    readonly instanceType?: string;
    /**
     * @schema CfnGroupPropsGroupComputeInstanceTypesWeights#weightedCapacity
     */
    readonly weightedCapacity?: number;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeInstanceTypesWeights' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeInstanceTypesWeights(obj: CfnGroupPropsGroupComputeInstanceTypesWeights | undefined): Record<string, any> | undefined;
/**
 * @schema LoadBalancersConfig
 */
export interface LoadBalancersConfig {
    /**
     * @schema LoadBalancersConfig#loadBalancers
     */
    readonly loadBalancers?: LoadBalancerConfig[];
}
/**
 * Converts an object of type 'LoadBalancersConfig' to JSON representation.
 */
export declare function toJson_LoadBalancersConfig(obj: LoadBalancersConfig | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationItf
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationItf {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItf#migrationHealthinessThreshold
     */
    readonly migrationHealthinessThreshold?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItf#weightStrategy
     */
    readonly weightStrategy?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItf#fixedTargetGroups
     */
    readonly fixedTargetGroups?: boolean;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItf#loadBalancers
     */
    readonly loadBalancers?: CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItf#targetGroupConfig
     */
    readonly targetGroupConfig?: CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationItf' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationItf(obj: CfnGroupPropsGroupComputeLaunchSpecificationItf | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationImages
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationImages {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationImages#id
     */
    readonly id?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationImages' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationImages(obj: CfnGroupPropsGroupComputeLaunchSpecificationImages | undefined): Record<string, any> | undefined;
/**
 * @schema Tag
 */
export interface Tag {
    /**
     * @schema Tag#tagKey
     */
    readonly tagKey?: string;
    /**
     * @schema Tag#tagValue
     */
    readonly tagValue?: string;
}
/**
 * Converts an object of type 'Tag' to JSON representation.
 */
export declare function toJson_Tag(obj: Tag | undefined): Record<string, any> | undefined;
/**
 * @schema BlockDeviceMapping
 */
export interface BlockDeviceMapping {
    /**
     * @schema BlockDeviceMapping#deviceName
     */
    readonly deviceName?: string;
    /**
     * @schema BlockDeviceMapping#noDevice
     */
    readonly noDevice?: string;
    /**
     * @schema BlockDeviceMapping#virtualName
     */
    readonly virtualName?: string;
    /**
     * @schema BlockDeviceMapping#ebs
     */
    readonly ebs?: BlockDeviceMappingEbs;
}
/**
 * Converts an object of type 'BlockDeviceMapping' to JSON representation.
 */
export declare function toJson_BlockDeviceMapping(obj: BlockDeviceMapping | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationIamRole
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationIamRole {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationIamRole#name
     */
    readonly name?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationIamRole#arn
     */
    readonly arn?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationIamRole' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationIamRole(obj: CfnGroupPropsGroupComputeLaunchSpecificationIamRole | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationCreditSpecification
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationCreditSpecification {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationCreditSpecification#cpuCredits
     */
    readonly cpuCredits?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationCreditSpecification' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationCreditSpecification(obj: CfnGroupPropsGroupComputeLaunchSpecificationCreditSpecification | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#description
     */
    readonly description?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#deviceIndex
     */
    readonly deviceIndex?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#secondaryPrivateIpAddressCount
     */
    readonly secondaryPrivateIpAddressCount?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#associatePublicIpAddress
     */
    readonly associatePublicIpAddress?: boolean;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#deleteOnTermination
     */
    readonly deleteOnTermination?: boolean;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#groups
     */
    readonly groups?: string[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#networkInterfaceId
     */
    readonly networkInterfaceId?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#privateIpAddresses
     */
    readonly privateIpAddresses?: CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfacesPrivateIpAddresses[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#subnetId
     */
    readonly subnetId?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces#associateIpv6Address
     */
    readonly associateIpv6Address?: boolean;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces(obj: CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfaces | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationCpuOptions
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationCpuOptions {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationCpuOptions#threadsPerCore
     */
    readonly threadsPerCore?: number;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationCpuOptions' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationCpuOptions(obj: CfnGroupPropsGroupComputeLaunchSpecificationCpuOptions | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification#volumes
     */
    readonly volumes?: ResourceTagSpecificationConfig;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification#snapshots
     */
    readonly snapshots?: ResourceTagSpecificationConfig;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification#amis
     */
    readonly amis?: ResourceTagSpecificationConfig;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification#enis
     */
    readonly enis?: ResourceTagSpecificationConfig;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification(obj: CfnGroupPropsGroupComputeLaunchSpecificationResourceTagSpecification | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions#httpTokens
     */
    readonly httpTokens?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions#httpPutResponseHopLimit
     */
    readonly httpPutResponseHopLimit?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions#instanceMetadataTags
     */
    readonly instanceMetadataTags?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions(obj: CfnGroupPropsGroupComputeLaunchSpecificationMetadataOptions | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupScalingMultipleMetricsMetrics
 */
export interface CfnGroupPropsGroupScalingMultipleMetricsMetrics {
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsMetrics#name
     */
    readonly name?: string;
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsMetrics#metricName
     */
    readonly metricName?: string;
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsMetrics#namespace
     */
    readonly namespace?: string;
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsMetrics#statistic
     */
    readonly statistic?: string;
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsMetrics#extendedStatistic
     */
    readonly extendedStatistic?: string;
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsMetrics#unit
     */
    readonly unit?: string;
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsMetrics#dimensions
     */
    readonly dimensions?: Dimension[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupScalingMultipleMetricsMetrics' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupScalingMultipleMetricsMetrics(obj: CfnGroupPropsGroupScalingMultipleMetricsMetrics | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupScalingMultipleMetricsExpressions
 */
export interface CfnGroupPropsGroupScalingMultipleMetricsExpressions {
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsExpressions#name
     */
    readonly name?: string;
    /**
     * @schema CfnGroupPropsGroupScalingMultipleMetricsExpressions#expression
     */
    readonly expression?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupScalingMultipleMetricsExpressions' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupScalingMultipleMetricsExpressions(obj: CfnGroupPropsGroupScalingMultipleMetricsExpressions | undefined): Record<string, any> | undefined;
/**
 * @schema Dimension
 */
export interface Dimension {
    /**
     * @schema Dimension#name
     */
    readonly name?: string;
    /**
     * @schema Dimension#value
     */
    readonly value?: string;
}
/**
 * Converts an object of type 'Dimension' to JSON representation.
 */
export declare function toJson_Dimension(obj: Dimension | undefined): Record<string, any> | undefined;
/**
 * @schema ScaleUpStepAdjustment
 */
export interface ScaleUpStepAdjustment {
    /**
     * @schema ScaleUpStepAdjustment#threshold
     */
    readonly threshold?: number;
    /**
     * @schema ScaleUpStepAdjustment#action
     */
    readonly action?: ScaleUpAction;
}
/**
 * Converts an object of type 'ScaleUpStepAdjustment' to JSON representation.
 */
export declare function toJson_ScaleUpStepAdjustment(obj: ScaleUpStepAdjustment | undefined): Record<string, any> | undefined;
/**
 * @schema ScaleUpAction
 */
export interface ScaleUpAction {
    /**
     * @schema ScaleUpAction#type
     */
    readonly type?: string;
    /**
     * @schema ScaleUpAction#adjustment
     */
    readonly adjustment?: string;
    /**
     * @schema ScaleUpAction#minTargetCapacity
     */
    readonly minTargetCapacity?: string;
    /**
     * @schema ScaleUpAction#target
     */
    readonly target?: string;
    /**
     * @schema ScaleUpAction#minimum
     */
    readonly minimum?: string;
    /**
     * @schema ScaleUpAction#maximum
     */
    readonly maximum?: string;
}
/**
 * Converts an object of type 'ScaleUpAction' to JSON representation.
 */
export declare function toJson_ScaleUpAction(obj: ScaleUpAction | undefined): Record<string, any> | undefined;
/**
 * @schema ScaleDownStepAdjustment
 */
export interface ScaleDownStepAdjustment {
    /**
     * @schema ScaleDownStepAdjustment#threshold
     */
    readonly threshold?: number;
    /**
     * @schema ScaleDownStepAdjustment#action
     */
    readonly action?: ScaleDownAction;
}
/**
 * Converts an object of type 'ScaleDownStepAdjustment' to JSON representation.
 */
export declare function toJson_ScaleDownStepAdjustment(obj: ScaleDownStepAdjustment | undefined): Record<string, any> | undefined;
/**
 * @schema ScaleDownAction
 */
export interface ScaleDownAction {
    /**
     * @schema ScaleDownAction#type
     */
    readonly type?: string;
    /**
     * @schema ScaleDownAction#adjustment
     */
    readonly adjustment?: string;
    /**
     * @schema ScaleDownAction#maxTargetCapacity
     */
    readonly maxTargetCapacity?: string;
    /**
     * @schema ScaleDownAction#target
     */
    readonly target?: string;
    /**
     * @schema ScaleDownAction#minimum
     */
    readonly minimum?: string;
    /**
     * @schema ScaleDownAction#maximum
     */
    readonly maximum?: string;
}
/**
 * Converts an object of type 'ScaleDownAction' to JSON representation.
 */
export declare function toJson_ScaleDownAction(obj: ScaleDownAction | undefined): Record<string, any> | undefined;
/**
 * @schema ScalingTargetPolicyPredictive
 */
export interface ScalingTargetPolicyPredictive {
    /**
     * @schema ScalingTargetPolicyPredictive#mode
     */
    readonly mode?: string;
}
/**
 * Converts an object of type 'ScalingTargetPolicyPredictive' to JSON representation.
 */
export declare function toJson_ScalingTargetPolicyPredictive(obj: ScalingTargetPolicyPredictive | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences#automaticRoll
     */
    readonly automaticRoll?: boolean;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences#batchSizePercentage
     */
    readonly batchSizePercentage?: number;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences#gracePeriod
     */
    readonly gracePeriod?: number;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences#strategy
     */
    readonly strategy?: BeanStalkStrategy;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences(obj: CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkDeploymentPreferences | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActions
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActions {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActions#platformUpdate
     */
    readonly platformUpdate?: CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActions' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActions(obj: CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActions | undefined): Record<string, any> | undefined;
/**
 * @schema EcsAutoScale
 */
export interface EcsAutoScale {
    /**
     * @schema EcsAutoScale#isEnabled
     */
    readonly isEnabled?: boolean;
    /**
     * @schema EcsAutoScale#cooldown
     */
    readonly cooldown?: number;
    /**
     * @schema EcsAutoScale#isAutoConfig
     */
    readonly isAutoConfig?: boolean;
    /**
     * @schema EcsAutoScale#shouldScaleDownNonServiceTasks
     */
    readonly shouldScaleDownNonServiceTasks?: boolean;
    /**
     * @schema EcsAutoScale#headroom
     */
    readonly headroom?: Headroom;
    /**
     * @schema EcsAutoScale#down
     */
    readonly down?: AutoScaleDown;
    /**
     * @schema EcsAutoScale#attributes
     */
    readonly attributes?: Attribute[];
}
/**
 * Converts an object of type 'EcsAutoScale' to JSON representation.
 */
export declare function toJson_EcsAutoScale(obj: EcsAutoScale | undefined): Record<string, any> | undefined;
/**
 * @schema EcsBatch
 */
export interface EcsBatch {
    /**
     * @schema EcsBatch#jobQueueNames
     */
    readonly jobQueueNames?: string[];
}
/**
 * Converts an object of type 'EcsBatch' to JSON representation.
 */
export declare function toJson_EcsBatch(obj: EcsBatch | undefined): Record<string, any> | undefined;
/**
 * @schema EcsOptimizeImages
 */
export interface EcsOptimizeImages {
    /**
     * @schema EcsOptimizeImages#shouldOptimizeEcsAmi
     */
    readonly shouldOptimizeEcsAmi?: boolean;
    /**
     * @schema EcsOptimizeImages#performAt
     */
    readonly performAt?: string;
    /**
     * @schema EcsOptimizeImages#timeWindows
     */
    readonly timeWindows?: string[];
}
/**
 * Converts an object of type 'EcsOptimizeImages' to JSON representation.
 */
export declare function toJson_EcsOptimizeImages(obj: EcsOptimizeImages | undefined): Record<string, any> | undefined;
/**
 * @schema KubernetesAutoScale
 */
export interface KubernetesAutoScale {
    /**
     * @schema KubernetesAutoScale#isEnabled
     */
    readonly isEnabled?: boolean;
    /**
     * @schema KubernetesAutoScale#isAutoConfig
     */
    readonly isAutoConfig?: boolean;
    /**
     * @schema KubernetesAutoScale#cooldown
     */
    readonly cooldown?: number;
    /**
     * @schema KubernetesAutoScale#headroom
     */
    readonly headroom?: KubernetesAutoScaleHeadroom;
    /**
     * @schema KubernetesAutoScale#resourceLimits
     */
    readonly resourceLimits?: KubernetesAutoScaleResourceLimits;
    /**
     * @schema KubernetesAutoScale#labels
     */
    readonly labels?: Attribute[];
    /**
     * @schema KubernetesAutoScale#down
     */
    readonly down?: AutoScaleDown;
}
/**
 * Converts an object of type 'KubernetesAutoScale' to JSON representation.
 */
export declare function toJson_KubernetesAutoScale(obj: KubernetesAutoScale | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationCodeDeployDeploymentGroups
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationCodeDeployDeploymentGroups {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationCodeDeployDeploymentGroups#applicationName
     */
    readonly applicationName?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationCodeDeployDeploymentGroups#deploymentGroupName
     */
    readonly deploymentGroupName?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationCodeDeployDeploymentGroups' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationCodeDeployDeploymentGroups(obj: CfnGroupPropsGroupThirdPartiesIntegrationCodeDeployDeploymentGroups | undefined): Record<string, any> | undefined;
/**
 * @schema NomadAutoScale
 */
export interface NomadAutoScale {
    /**
     * @schema NomadAutoScale#isEnabled
     */
    readonly isEnabled?: boolean;
    /**
     * @schema NomadAutoScale#isAutoConfig
     */
    readonly isAutoConfig?: boolean;
    /**
     * @schema NomadAutoScale#cooldown
     */
    readonly cooldown?: number;
    /**
     * @schema NomadAutoScale#headroom
     */
    readonly headroom?: Headroom;
    /**
     * @schema NomadAutoScale#constraints
     */
    readonly constraints?: Attribute[];
    /**
     * @schema NomadAutoScale#down
     */
    readonly down?: AutoScaleDown;
}
/**
 * Converts an object of type 'NomadAutoScale' to JSON representation.
 */
export declare function toJson_NomadAutoScale(obj: NomadAutoScale | undefined): Record<string, any> | undefined;
/**
 * @schema TlsConfig
 */
export interface TlsConfig {
    /**
     * @schema TlsConfig#tlsEnabled
     */
    readonly tlsEnabled?: boolean;
    /**
     * @schema TlsConfig#certificate
     */
    readonly certificate?: string;
    /**
     * @schema TlsConfig#privateKey
     */
    readonly privateKey?: string;
}
/**
 * Converts an object of type 'TlsConfig' to JSON representation.
 */
export declare function toJson_TlsConfig(obj: TlsConfig | undefined): Record<string, any> | undefined;
/**
 * @schema DockerSwarmAutoScale
 */
export interface DockerSwarmAutoScale {
    /**
     * @schema DockerSwarmAutoScale#isEnabled
     */
    readonly isEnabled?: boolean;
    /**
     * @schema DockerSwarmAutoScale#cooldown
     */
    readonly cooldown?: number;
    /**
     * @schema DockerSwarmAutoScale#headroom
     */
    readonly headroom?: Headroom;
    /**
     * @schema DockerSwarmAutoScale#labels
     */
    readonly labels?: Attribute[];
    /**
     * @schema DockerSwarmAutoScale#down
     */
    readonly down?: AutoScaleDown;
}
/**
 * Converts an object of type 'DockerSwarmAutoScale' to JSON representation.
 */
export declare function toJson_DockerSwarmAutoScale(obj: DockerSwarmAutoScale | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains#hostedZoneId
     */
    readonly hostedZoneId?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains#spotinstAccountId
     */
    readonly spotinstAccountId?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains#recordSetType
     */
    readonly recordSetType?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains#recordSets
     */
    readonly recordSets?: CfnGroupPropsGroupThirdPartiesIntegrationRoute53DomainsRecordSets[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains(obj: CfnGroupPropsGroupThirdPartiesIntegrationRoute53Domains | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationGitlabRunner
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationGitlabRunner {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationGitlabRunner#isEnabled
     */
    readonly isEnabled?: boolean;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationGitlabRunner' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationGitlabRunner(obj: CfnGroupPropsGroupThirdPartiesIntegrationGitlabRunner | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationDatadogMetricsToReport
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationDatadogMetricsToReport {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationDatadogMetricsToReport#metricsList
     */
    readonly metricsList?: string[];
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationDatadogMetricsToReport#tags
     */
    readonly tags?: Tag[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationDatadogMetricsToReport' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationDatadogMetricsToReport(obj: CfnGroupPropsGroupThirdPartiesIntegrationDatadogMetricsToReport | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod#ssh
     */
    readonly ssh?: CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodSsh;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod#jnlp
     */
    readonly jnlp?: CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod#manuallyConnection
     */
    readonly manuallyConnection?: boolean;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod(obj: CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethod | undefined): Record<string, any> | undefined;
/**
 * @schema ResourceRequirement
 */
export interface ResourceRequirement {
    /**
     * @schema ResourceRequirement#minimum
     */
    readonly minimum?: number;
    /**
     * @schema ResourceRequirement#maximum
     */
    readonly maximum?: number;
}
/**
 * Converts an object of type 'ResourceRequirement' to JSON representation.
 */
export declare function toJson_ResourceRequirement(obj: ResourceRequirement | undefined): Record<string, any> | undefined;
/**
 * @schema LoadBalancerConfig
 */
export interface LoadBalancerConfig {
    /**
     * @schema LoadBalancerConfig#name
     */
    readonly name?: string;
    /**
     * @schema LoadBalancerConfig#arn
     */
    readonly arn?: string;
    /**
     * @schema LoadBalancerConfig#type
     */
    readonly type?: string;
    /**
     * @schema LoadBalancerConfig#balancerId
     */
    readonly balancerId?: string;
    /**
     * @schema LoadBalancerConfig#targetSetId
     */
    readonly targetSetId?: string;
    /**
     * @schema LoadBalancerConfig#azAwareness
     */
    readonly azAwareness?: boolean;
    /**
     * @schema LoadBalancerConfig#autoWeight
     */
    readonly autoWeight?: boolean;
}
/**
 * Converts an object of type 'LoadBalancerConfig' to JSON representation.
 */
export declare function toJson_LoadBalancerConfig(obj: LoadBalancerConfig | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers#loadBalancerArn
     */
    readonly loadBalancerArn?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers#listenerRules
     */
    readonly listenerRules?: CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRules[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers#defaultStaticTargetGroups
     */
    readonly defaultStaticTargetGroups?: CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersDefaultStaticTargetGroups[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers(obj: CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancers | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#vpcId
     */
    readonly vpcId?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#healthCheckPath
     */
    readonly healthCheckPath?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#healthCheckProtocol
     */
    readonly healthCheckProtocol?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#healthCheckPort
     */
    readonly healthCheckPort?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#healthCheckIntervalSeconds
     */
    readonly healthCheckIntervalSeconds?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#healthCheckTimeoutSeconds
     */
    readonly healthCheckTimeoutSeconds?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#healthyThresholdCount
     */
    readonly healthyThresholdCount?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#unhealthyThresholdCount
     */
    readonly unhealthyThresholdCount?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#port
     */
    readonly port?: number;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#protocol
     */
    readonly protocol?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#protocolVersion
     */
    readonly protocolVersion?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#tags
     */
    readonly tags?: Tag[];
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig#matcher
     */
    readonly matcher?: CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfigMatcher;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig(obj: CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfig | undefined): Record<string, any> | undefined;
/**
 * @schema BlockDeviceMappingEbs
 */
export interface BlockDeviceMappingEbs {
    /**
     * @schema BlockDeviceMappingEbs#deleteOnTermination
     */
    readonly deleteOnTermination?: boolean;
    /**
     * @schema BlockDeviceMappingEbs#encrypted
     */
    readonly encrypted?: boolean;
    /**
     * @schema BlockDeviceMappingEbs#iops
     */
    readonly iops?: number;
    /**
     * @schema BlockDeviceMappingEbs#kmsKeyId
     */
    readonly kmsKeyId?: string;
    /**
     * @schema BlockDeviceMappingEbs#snapshotId
     */
    readonly snapshotId?: string;
    /**
     * @schema BlockDeviceMappingEbs#volumeSize
     */
    readonly volumeSize?: number;
    /**
     * @schema BlockDeviceMappingEbs#volumeType
     */
    readonly volumeType?: string;
    /**
     * @schema BlockDeviceMappingEbs#throughput
     */
    readonly throughput?: number;
    /**
     * @schema BlockDeviceMappingEbs#dynamicVolumeSize
     */
    readonly dynamicVolumeSize?: BlockDeviceMappingEbsDynamicVolumeSize;
}
/**
 * Converts an object of type 'BlockDeviceMappingEbs' to JSON representation.
 */
export declare function toJson_BlockDeviceMappingEbs(obj: BlockDeviceMappingEbs | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfacesPrivateIpAddresses
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfacesPrivateIpAddresses {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfacesPrivateIpAddresses#privateIpAddress
     */
    readonly privateIpAddress?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfacesPrivateIpAddresses#primary
     */
    readonly primary?: boolean;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfacesPrivateIpAddresses' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfacesPrivateIpAddresses(obj: CfnGroupPropsGroupComputeLaunchSpecificationNetworkInterfacesPrivateIpAddresses | undefined): Record<string, any> | undefined;
/**
 * @schema ResourceTagSpecificationConfig
 */
export interface ResourceTagSpecificationConfig {
    /**
     * @schema ResourceTagSpecificationConfig#shouldTag
     */
    readonly shouldTag?: boolean;
}
/**
 * Converts an object of type 'ResourceTagSpecificationConfig' to JSON representation.
 */
export declare function toJson_ResourceTagSpecificationConfig(obj: ResourceTagSpecificationConfig | undefined): Record<string, any> | undefined;
/**
 * @schema BeanStalkStrategy
 */
export interface BeanStalkStrategy {
    /**
     * @schema BeanStalkStrategy#action
     */
    readonly action?: string;
    /**
     * @schema BeanStalkStrategy#shouldDrainInstances
     */
    readonly shouldDrainInstances?: boolean;
}
/**
 * Converts an object of type 'BeanStalkStrategy' to JSON representation.
 */
export declare function toJson_BeanStalkStrategy(obj: BeanStalkStrategy | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate#performAt
     */
    readonly performAt?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate#timeWindow
     */
    readonly timeWindow?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate#updateLevel
     */
    readonly updateLevel?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate#instanceRefreshEnabled
     */
    readonly instanceRefreshEnabled?: boolean;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate(obj: CfnGroupPropsGroupThirdPartiesIntegrationElasticBeanstalkManagedActionsPlatformUpdate | undefined): Record<string, any> | undefined;
/**
 * @schema Headroom
 */
export interface Headroom {
    /**
     * @schema Headroom#cpuPerUnit
     */
    readonly cpuPerUnit?: number;
    /**
     * @schema Headroom#memoryPerUnit
     */
    readonly memoryPerUnit?: number;
    /**
     * @schema Headroom#numOfUnits
     */
    readonly numOfUnits?: number;
}
/**
 * Converts an object of type 'Headroom' to JSON representation.
 */
export declare function toJson_Headroom(obj: Headroom | undefined): Record<string, any> | undefined;
/**
 * @schema AutoScaleDown
 */
export interface AutoScaleDown {
    /**
     * @schema AutoScaleDown#evaluationPeriods
     */
    readonly evaluationPeriods?: number;
    /**
     * @schema AutoScaleDown#maxScaleDownPercentage
     */
    readonly maxScaleDownPercentage?: number;
}
/**
 * Converts an object of type 'AutoScaleDown' to JSON representation.
 */
export declare function toJson_AutoScaleDown(obj: AutoScaleDown | undefined): Record<string, any> | undefined;
/**
 * @schema Attribute
 */
export interface Attribute {
    /**
     * @schema Attribute#key
     */
    readonly key?: string;
    /**
     * @schema Attribute#value
     */
    readonly value?: string;
}
/**
 * Converts an object of type 'Attribute' to JSON representation.
 */
export declare function toJson_Attribute(obj: Attribute | undefined): Record<string, any> | undefined;
/**
 * @schema KubernetesAutoScaleHeadroom
 */
export interface KubernetesAutoScaleHeadroom {
    /**
     * @schema KubernetesAutoScaleHeadroom#cpuPerUnit
     */
    readonly cpuPerUnit?: number;
    /**
     * @schema KubernetesAutoScaleHeadroom#memoryPerUnit
     */
    readonly memoryPerUnit?: number;
    /**
     * @schema KubernetesAutoScaleHeadroom#gpuPerUnit
     */
    readonly gpuPerUnit?: number;
    /**
     * @schema KubernetesAutoScaleHeadroom#numOfUnits
     */
    readonly numOfUnits?: number;
}
/**
 * Converts an object of type 'KubernetesAutoScaleHeadroom' to JSON representation.
 */
export declare function toJson_KubernetesAutoScaleHeadroom(obj: KubernetesAutoScaleHeadroom | undefined): Record<string, any> | undefined;
/**
 * @schema KubernetesAutoScaleResourceLimits
 */
export interface KubernetesAutoScaleResourceLimits {
    /**
     * @schema KubernetesAutoScaleResourceLimits#maxVCpu
     */
    readonly maxVCpu?: number;
    /**
     * @schema KubernetesAutoScaleResourceLimits#maxMemoryGib
     */
    readonly maxMemoryGib?: number;
}
/**
 * Converts an object of type 'KubernetesAutoScaleResourceLimits' to JSON representation.
 */
export declare function toJson_KubernetesAutoScaleResourceLimits(obj: KubernetesAutoScaleResourceLimits | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53DomainsRecordSets
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationRoute53DomainsRecordSets {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53DomainsRecordSets#name
     */
    readonly name?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationRoute53DomainsRecordSets#usePublicDns
     */
    readonly usePublicDns?: boolean;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationRoute53DomainsRecordSets' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationRoute53DomainsRecordSets(obj: CfnGroupPropsGroupThirdPartiesIntegrationRoute53DomainsRecordSets | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodSsh
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodSsh {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodSsh#sshPublicKey
     */
    readonly sshPublicKey?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodSsh' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodSsh(obj: CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodSsh | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp
 */
export interface CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp {
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp#masterIP
     */
    readonly masterIp?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp#masterPort
     */
    readonly masterPort?: number;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp#password
     */
    readonly password?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp#userName
     */
    readonly userName?: string;
    /**
     * @schema CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp#token
     */
    readonly token?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp(obj: CfnGroupPropsGroupThirdPartiesIntegrationJenkinsConnectionMethodJnlp | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRules
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRules {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRules#ruleArn
     */
    readonly ruleArn?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRules#staticTargetGroups
     */
    readonly staticTargetGroups?: CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRulesStaticTargetGroups[];
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRules' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRules(obj: CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRules | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersDefaultStaticTargetGroups
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersDefaultStaticTargetGroups {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersDefaultStaticTargetGroups#arn
     */
    readonly arn?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersDefaultStaticTargetGroups#percentage
     */
    readonly percentage?: number;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersDefaultStaticTargetGroups' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersDefaultStaticTargetGroups(obj: CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersDefaultStaticTargetGroups | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfigMatcher
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfigMatcher {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfigMatcher#httpCode
     */
    readonly httpCode?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfigMatcher#grpcCode
     */
    readonly grpcCode?: string;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfigMatcher' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfigMatcher(obj: CfnGroupPropsGroupComputeLaunchSpecificationItfTargetGroupConfigMatcher | undefined): Record<string, any> | undefined;
/**
 * @schema BlockDeviceMappingEbsDynamicVolumeSize
 */
export interface BlockDeviceMappingEbsDynamicVolumeSize {
    /**
     * @schema BlockDeviceMappingEbsDynamicVolumeSize#baseSize
     */
    readonly baseSize?: number;
    /**
     * @schema BlockDeviceMappingEbsDynamicVolumeSize#resource
     */
    readonly resource?: string;
    /**
     * @schema BlockDeviceMappingEbsDynamicVolumeSize#sizePerResourceUnit
     */
    readonly sizePerResourceUnit?: number;
}
/**
 * Converts an object of type 'BlockDeviceMappingEbsDynamicVolumeSize' to JSON representation.
 */
export declare function toJson_BlockDeviceMappingEbsDynamicVolumeSize(obj: BlockDeviceMappingEbsDynamicVolumeSize | undefined): Record<string, any> | undefined;
/**
 * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRulesStaticTargetGroups
 */
export interface CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRulesStaticTargetGroups {
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRulesStaticTargetGroups#arn
     */
    readonly arn?: string;
    /**
     * @schema CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRulesStaticTargetGroups#percentage
     */
    readonly percentage?: number;
}
/**
 * Converts an object of type 'CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRulesStaticTargetGroups' to JSON representation.
 */
export declare function toJson_CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRulesStaticTargetGroups(obj: CfnGroupPropsGroupComputeLaunchSpecificationItfLoadBalancersListenerRulesStaticTargetGroups | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Spot::Elastigroup::Group`
 *
 * @cloudformationResource Spot::Elastigroup::Group
 * @stability external
 * @link http://unknown-url
 */
export declare class CfnGroup extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Spot::Elastigroup::Group";
    /**
     * Resource props.
     */
    readonly props: CfnGroupProps;
    /**
     * Create a new `Spot::Elastigroup::Group`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnGroupProps);
}
